@@ -101,25 +101,23 @@ class Globals:
 
         if globalsInstanceIsNone() :
 
+            self.logStatus = EnvironmentHelper.update(log.LOG, logStatus, default=DEFAULT_LOG_STATUS)
+            self.successStatus = EnvironmentHelper.update(log.SUCCESS, successStatus, default=DEFAULT_SUCCESS_STATUS)
+            self.settingStatus = EnvironmentHelper.update(log.SETTING, settingStatus, default=DEFAULT_SETTING_STATUS)
+            self.debugStatus = EnvironmentHelper.update(log.DEBUG, debugStatus, default=DEFAULT_DEBUG_STATUS)
+            self.warningStatus = EnvironmentHelper.update(log.WARNING, warningStatus, default=DEFAULT_WARNING_STATUS)
+            self.failureStatus = EnvironmentHelper.update(log.FAILURE, failureStatus, default=DEFAULT_FAILURE_STATUS)
+            self.wrapperStatus = EnvironmentHelper.update(log.WRAPPER, wrapperStatus, default=DEFAULT_WRAPPER_STATUS)
+            self.errorStatus = EnvironmentHelper.update(log.ERROR, errorStatus, default=DEFAULT_ERROR_STATUS)
+            self.testStatus = EnvironmentHelper.update(log.TEST, testStatus, default=DEFAULT_TEST_STATUS)
+            log.loadSettings()
+
             self.filePath = filePath
             self.charactereFilterList = Globals.CHARACTERE_FILTER
             self.nodeIgnoreList = Globals.NODE_IGNORE_LIST
             self.encoding = encoding
 
-            self.loadLocalConfiguration(
-                loadLocalConfig,
-                logStatus,
-                successStatus,
-                settingStatus,
-                debugStatus,
-                warningStatus,
-                failureStatus,
-                wrapperStatus,
-                errorStatus,
-                testStatus,
-                printRootPathStatus,
-                globalsEverything
-            )
+            self.loadLocalConfiguration(loadLocalConfig, printRootPathStatus, globalsEverything)
 
             self.setting(f'{self.__class__.__name__}{c.DOT}filePath: {self.filePath}')
             self.setting(f'__file__: {__file__}')
@@ -144,37 +142,14 @@ class Globals:
         self.updateDependencyStatus = self.getSetting(AttributeKey.DEPENDENCY_UPDATE)
         self.rootPathTree = {}
 
-    def loadLocalConfiguration(
-        self,
-        loadLocalConfig,
-        logStatus,
-        successStatus,
-        settingStatus,
-        debugStatus,
-        warningStatus,
-        failureStatus,
-        wrapperStatus,
-        errorStatus,
-        testStatus,
-        printRootPathStatus,
-        globalsEverything
-    ) :
-        self.logStatus = EnvironmentHelper.update(log.LOG, logStatus, default=DEFAULT_LOG_STATUS)
-        self.successStatus = EnvironmentHelper.update(log.SUCCESS, successStatus, default=DEFAULT_SUCCESS_STATUS)
-        self.settingStatus = EnvironmentHelper.update(log.SETTING, settingStatus, default=DEFAULT_SETTING_STATUS)
-        self.debugStatus = EnvironmentHelper.update(log.DEBUG, debugStatus, default=DEFAULT_DEBUG_STATUS)
-        self.warningStatus = EnvironmentHelper.update(log.WARNING, warningStatus, default=DEFAULT_WARNING_STATUS)
-        self.failureStatus = EnvironmentHelper.update(log.FAILURE, failureStatus, default=DEFAULT_FAILURE_STATUS)
-        self.wrapperStatus = EnvironmentHelper.update(log.WRAPPER, wrapperStatus, default=DEFAULT_WRAPPER_STATUS)
-        self.errorStatus = EnvironmentHelper.update(log.ERROR, errorStatus, default=DEFAULT_ERROR_STATUS)
-        self.testStatus = EnvironmentHelper.update(log.TEST, testStatus, default=DEFAULT_TEST_STATUS)
+    def loadLocalConfiguration(self, loadLocalConfig, printRootPathStatus, globalsEverything) :
         self.loadLocalConfig = loadLocalConfig
         self.localConfiguration = {}
         if self.loadLocalConfig :
             try :
                 self.localConfiguration = self.getSettingTree(settingFilePath=Globals.LOCAL_CONFIGURATION_FILE_NAME,settingTree=None)
             except Exception as exception :
-                log.log(self.__class__,f'Failed to load {Globals.LOCAL_CONFIGURATION_FILE_NAME} settings', exception=exception)
+                self.log(f'Failed to load {Globals.LOCAL_CONFIGURATION_FILE_NAME} settings', exception=exception)
             keyQuery = SettingHelper.querySetting(AttributeKey.KW_KEY,self.localConfiguration)
             keyValueQuery = {}
             for key,value in keyQuery.items() :
@@ -486,23 +461,25 @@ class Globals:
                 log.error(self.__class__,f'Not possible to run {commandFirstTry}',Exception(f'Both attempt failed'))
 
     def getApiName(self):
+        apiName = None
         try :
-            return self.getSetting(AttributeKey.API_NAME)
+            apiName = self.getSetting(AttributeKey.API_NAME)
         except Exception as exception :
-            self.failure('Not possible to get api name', exception)
+            self.warning(f'Not possible to get api name. Returning {apiName} by default', exception=exception)
+        return apiName
 
     def getExtension(self):
         extension = Globals.EXTENSION
         try :
             extension = self.getSetting(AttributeKey.API_EXTENSION)
         except Exception as exception :
-            self.failure('Not possible to get api extenion. Returning default estension', exception)
+            self.warning(f'Not possible to get api extenion. Returning {extension} by default', exception=exception)
         return extension
 
     def getStaticPackagePath(self) :
         staticPackage = self.getSetting(AttributeKey.PYTHON_STATIC_PACKAGE)
         if ObjectHelper.isNone(staticPackage) :
-            if EnvironmentHelper.isLinux() == 'linux' :
+            if EnvironmentHelper.isLinux() :
                 staticPackage = str(site.getusersitepackages())
                 self.log(f'Static package (before handlings): "{staticPackage}"')
             else :
@@ -532,9 +509,9 @@ class Globals:
         if c.TRUE == self.debugStatus :
             log.debug(self.__class__,message)
 
-    def warning(self,message):
+    def warning(self, message, exception=None):
         if c.TRUE == self.warningStatus :
-            log.warning(self.__class__,message)
+            log.warning(self.__class__, message, exception=exception)
 
     def error(self,message,exception):
         if c.TRUE == self.errorStatus :
@@ -671,12 +648,12 @@ def importModule(resourceModuleName, muteLogs=False, ignoreList=IGNORE_MODULE_LI
             module = importlib.import_module(resourceModuleName)
         except Exception as exception:
             if not muteLogs :
-                log.warning(importResource, f'Not possible to import "{resourceModuleName}" module. Going for a second attempt', exception=exception)
+                log.log(importResource, f'Not possible to import "{resourceModuleName}" module. Going for a second attempt', exception=exception)
             try :
                 module = __import__(resourceModuleName)
             except :
                 if not muteLogs :
-                    log.failure(importResource, f'Not possible to import "{resourceModuleName}" module in the second attempt either. Returning "{module}" by default', exception)
+                    log.warning(importResource, f'Not possible to import "{resourceModuleName}" module in the second attempt either. Returning "{module}" by default', exception=exception)
         return module
 
 def importResource(resourceName, resourceModuleName=None, muteLogs=False, ignoreList=IGNORE_REOURCE_LIST) :
@@ -693,7 +670,7 @@ def importResource(resourceName, resourceModuleName=None, muteLogs=False, ignore
                     resource = ReflectionHelper.getAttributeOrMethod(resource, name)
             except Exception as exception :
                 if not muteLogs :
-                    log.failure(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module', exception=exception)
+                    log.warning(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module', exception=exception)
             return resource
 
 def runBeforeTest(instanceList, logLevel=log.LOG, muteLogs=True) :
